Index: Source/core/css/ElementRuleCollector.h |
diff --git a/Source/core/css/ElementRuleCollector.h b/Source/core/css/ElementRuleCollector.h |
index d66d4516e09c5d892e60a9433b99d1bc6012b267..9670d832be32286e8db02c2154cd524922d99fca 100644 |
--- a/Source/core/css/ElementRuleCollector.h |
+++ b/Source/core/css/ElementRuleCollector.h |
@@ -101,12 +101,12 @@ public: |
// ElementRuleCollector is designed to be used as a stack object. |
// Create one, ask what rules the ElementResolveContext matches |
// and then let it go out of scope. |
// FIXME: Currently it modifies the LayoutStyle but should not! |
class ElementRuleCollector { |
STACK_ALLOCATED(); |
WTF_MAKE_NONCOPYABLE(ElementRuleCollector); |
public: |
- ElementRuleCollector(const ElementResolveContext&, const SelectorFilter&, LayoutStyle* = 0); |
+ ElementRuleCollector(const ElementResolveContext&, const SelectorFilter&, ComputedStyle* = 0); |
~ElementRuleCollector(); |
void setMode(SelectorChecker::Mode mode) { m_mode = mode; } |
@@ -157,7 +157,7 @@ private: |
private: |
const ElementResolveContext& m_context; |
const SelectorFilter& m_selectorFilter; |
- RefPtr<LayoutStyle> m_style; // FIXME: This can be mutated during matching! |
+ RefPtr<ComputedStyle> m_style; // FIXME: This can be mutated during matching! |
PseudoStyleRequest m_pseudoStyleRequest; |
SelectorChecker::Mode m_mode; |
@@ -101,12 +101,12 @@ public: |
// Create one, ask what rules the ElementResolveContext matches |
// and then let it go out of scope. |
-// FIXME: Currently it modifies the LayoutStyle but should not! |
+// FIXME: Currently it modifies the ComputedStyle but should not! |
class ElementRuleCollector { |
STACK_ALLOCATED(); |